package com.bonus.sgzb.machine.service;

import com.bonus.sgzb.machine.damain.MaHouse;
import com.bonus.sgzb.machine.vo.MaLabelBindVO;

import java.util.List;

/**
 * 机具设备标签ma_label_bind(MaLabelBind)表服务接口
 *
 * @author makejava
 * @since 2023-11-28 16:37:51
 */
public interface IMaLabelBindService {

    /**
     * 查询标签绑定管理列表
     * @param typeName
     * @return
     */
    List<MaLabelBindVO> selectMaLabelList(String typeName);

    /**
     * 批量绑定
     * @param labelIds
     * @return
     */
    int batchBindByIds(Long[] labelIds);

    /**
     * 标签解绑
     * @param labelId
     * @return
     */
    int batchNoBindByIds(Long labelId);

    /**
     * 导入标签管理数据
     * @param maLabelBindList 导入数据
     * @param updateSupport 存在是否更新
     * @param operName 操作人
     * @return
     */
    String importMaLabel(List<MaLabelBindVO> maLabelBindList, boolean updateSupport, String operName);

    /**
     * 修改标签管理数据
     * @param maLabelBindVO
     * @return
     */
    void updatetMaLabel(MaLabelBindVO maLabelBindVO);
}

